@@ -48,6 +48,7 @@ from sphinx.util.docfields import DocFieldTransformer
 __version__ = open(path.join(path.dirname(__file__),
                    "version.lisp-expr")).read().strip('"')
 
+
 ALL_TYPES = ["macro", "function", "genericFunction",
              "setf", "variable", "type"]
 upper_symbols = re.compile("([^a-z\s\"`]*[A-Z]{2,}[^a-z\s\"`:]*)($|\s)")
@@ -64,7 +65,7 @@ lambda_list_keywords = ["&allow-other-keys", "&key",
 
 
 def record_use(package, symbol_name, objtype):
-    """record unused package symbols."""
+    """Record unused package symbols."""
     symbol = symbol_name.upper()
     USED_SYMBOLS[package].setdefault(symbol, []).append(objtype)
 
@@ -107,7 +108,7 @@ def _read_from(tokens):
 
 
 def parse_specializer_symbol(symbol, package):
-    """parse symbols, for specializers"""
+    """Parse symbols, for specializers"""
     symbol = symbol.upper()
     if symbol.startswith(":"):
         return "KEYWORD" + symbol
@@ -228,7 +229,7 @@ def specializer(sexp, state):
     return node
 
 
-def specializer_xref(symbol, sexp, state):
+def specializer_xref(symbol, sexp, state, package=None):
     result = StringIO()
     first = True
     for atom in sexp:
@@ -239,6 +240,11 @@ def specializer_xref(symbol, sexp, state):
 
         if atom.startswith("KEYWORD:"):
             result.write("(EQL :%s)" % atom.split(":")[-1])
+        elif package:
+            if atom.startswith(package + ":"):
+                result.write(atom.split(":")[-1])
+            else:
+                result.write(atom)
         else:
             result.write(atom)
 
@@ -253,8 +259,10 @@ def specializer_xref(symbol, sexp, state):
 
 
 def qualify_sexp(package, sexp):
-    """if the sexp contains atoms that don't have a package
-    then qualify them."""
+    """If the sexp contains atoms that don't have a package then qualify
+    them.
+
+    """
     sexp_ret = []
     for atom in sexp:
         if atom.startswith(":"):
@@ -267,7 +275,7 @@ def qualify_sexp(package, sexp):
 
 
 def fieldlist_index(node):
-    """find the index of a field list in a content node."""
+    """Find the index of a field list in a content node."""
     for i, n in enumerate(node):
         if isinstance(n, nodes.field_list):
             return i
@@ -487,9 +495,9 @@ class CLsExp(ObjectDescription):
         return result
 
     def cl_doc_string(self, objtype=None):
-        """
-        Resolve a symbols doc string. Will raise KeyError if the
-        symbol can't be found.
+        """Resolve a symbols doc string. Will raise KeyError if the symbol
+        can't be found.
+
         """
         package = self.env.temp_data.get('cl:package')
         name = self.cl_symbol_name()
@@ -516,7 +524,7 @@ class CLGeneric(CLsExp):
         if specializers:
             description.append(nodes.paragraph(text="Specializes:"))
             spec = nodes.bullet_list()
-            spec += [specializer_xref(package + ":" + name, s, self.state)
+            spec += [specializer_xref(package + ":" + name, s, self.state, package)
                      for s in specializers]
             description.append(spec)
         return result
@@ -596,9 +604,9 @@ class CLMethod(CLsExp):
             self.indexnode['entries'].append(('single', indextext, indexname, ''))
 
     def cl_doc_string(self):
-        """
-        Resolve a symbols doc string. Will raise KeyError if the
-        symbol can't be found.
+        """Resolve a symbols doc string. Will raise KeyError if the symbol
+        can't be found.
+
         """
         package = self.env.temp_data.get('cl:package')
         name = self.cl_symbol_name()
@@ -633,9 +641,9 @@ class CLMethod(CLsExp):
 
 
 class CLCurrentPackage(Directive):
-    """
-    This directive is just to tell Sphinx that we're documenting stuff in
-    namespace foo.
+    """This directive is just to tell Sphinx that we're documenting stuff
+    in namespace foo.
+
     """
 
     has_content = False
@@ -707,7 +715,8 @@ class CLDomain(Domain):
 
     def find_obj(self, env, name):
         """Find a Lisp symbol for "name", perhaps using the given package
-        Returns a list of (name, object entry) tuples.
+        Return a list of (name, object entry) tuples.
+
         """
         symbols = self.data['symbols']
         name = name.lower()
@@ -728,7 +737,8 @@ class CLDomain(Domain):
 
     def find_method(self, env, name, node):
         """Find a Lisp symbol for "name", perhaps using the given package
-        Returns a list of (name, object entry) tuples.
+        Return a list of (name, object entry) tuples.
+
         """
         methods = self.data['methods']
         name = name.lower()
@@ -806,8 +816,10 @@ def save_cldomain_output(output):
 
 
 def index_package(package, package_path, quicklisp, lisps):
-    """Call an external lisp program that will return a dictionary of
-    doc strings for all public symbols."""
+    """Call an external lisp program that will return a dictionary of doc
+    strings for all public symbols.
+
+    """
     cl_launch_exe = [which("cl-launch")[0]]
     cl_launch_command = cl_launch_args(lisps)
     cldomain_args = ["--", "--package", package, "--path", package_path]
@@ -815,15 +827,15 @@ def index_package(package, package_path, quicklisp, lisps):
     env.update({"CLDOMAIN": path.abspath(path.dirname(__file__)) + "/",
                 "QUICKLISP": quicklisp})
 
-    output = subprocess.check_output(cl_launch_exe + cl_launch_command + cldomain_args,
+    raw_output = subprocess.check_output(cl_launch_exe + cl_launch_command + cldomain_args,
                                      env=env)
-    output = "\n".join([line for line in output.split("\n")
+    output = "\n".join([line for line in raw_output.split("\n")
                         if not line.startswith(";")])
 
     try:
         lisp_data = json.loads(output)
     except:
-        dump_path = save_cldomain_output(output)
+        dump_path = save_cldomain_output(raw_output)
         error = sys.stderr
         print >>error, red('A error occurred with the json output from cldomain\'s'
                            ' lisp inspector,  this has been dumped to %s if you '
@@ -973,7 +985,8 @@ def which(name, flags=os.X_OK):
 
 
 def cl_launch_args(lisps=None):
-    quicklisp="""
+    quicklisp = """
+#-quicklisp
 (let ((quicklisp-init (merge-pathnames (make-pathname :name "setup"
                                                       :type "lisp")
                                        (concatenate 'string (asdf/os:getenv "QUICKLISP")
@@ -994,11 +1007,11 @@ def cl_launch_args(lisps=None):
 """
     args = []
     if lisps:
-        args.extend(["--lisps", lisps])
+        args.extend(["--lisp", lisps])
     args.extend(["--init", quicklisp,
-            "--init", system,
-            "--init", "(asdf:initialize-source-registry)",
-            "--init", "(require 'quicklisp)",
-            "--init", quickload,
-            "--init", "(sphinxcontrib.cldomain:main)"])
+                 "--init", system,
+                 "--init", "(asdf:initialize-source-registry)",
+                 "--init", "(require 'quicklisp)",
+                 "--init", quickload,
+                 "--init", "(sphinxcontrib.cldomain:main)"])
     return args
